@@ -273,7 +273,7 @@ static const char* detectPci(const FFGPUOptions* options, FFlist* gpus, FFstrbuf
                 .memory = options->driverSpecific ? &gpu->dedicated : NULL,
                 .coreCount = options->driverSpecific ? (uint32_t*) &gpu->coreCount : NULL,
                 .type = &gpu->type,
-                .frequency = &gpu->frequency,
+                .frequency = options->driverSpecific ? &gpu->frequency : NULL,
             }, "libnvidia-ml.so");
         }
 
