@@ -499,6 +499,20 @@ static bool getTerminalVersionKitty(FFstrbuf* exe, FFstrbuf* version)
     //kitty 0.21.2 created by Kovid Goyal
     return getExeVersionGeneral(exe, version);
 }
+
+FF_MAYBE_UNUSED static bool getTerminalVersionPtyxis(FF_MAYBE_UNUSED FFstrbuf* exe, FFstrbuf* version)
+{
+    if(ffProcessAppendStdOut(version, (char* const[]) {
+        "ptyxis",
+        "--version",
+        NULL
+    }) != NULL)
+        return false;
+
+    ffStrbufSubstrBeforeFirstC(version, '\n');
+    ffStrbufSubstrAfterFirstC(version, ' ');
+    return true;
+}
 #endif
 
 #ifdef _WIN32
@@ -595,6 +609,9 @@ bool fftsGetTerminalVersion(FFstrbuf* processName, FF_MAYBE_UNUSED FFstrbuf* exe
     )
         return getTerminalVersionUrxvt(exe, version);
 
+    if(ffStrbufIgnCaseEqualS(processName, "ptyxis-agent"))
+        return getTerminalVersionPtyxis(exe, version);
+
     #endif
 
     #ifdef _WIN32
