@@ -234,10 +234,13 @@ static bool printSpecificCommandHelp(const char* command)
                     }
                 }
 
+                yyjson_doc_free(doc);
                 return true;
             }
         }
     }
+
+    yyjson_doc_free(doc);
     return false;
 }
 
@@ -262,6 +265,11 @@ static void listAvailablePresets(bool pretty)
         ffStrbufAppendS(path, "fastfetch/presets/");
         ffListFilesRecursively(path->chars, pretty);
     }
+
+    FF_STRBUF_AUTO_DESTROY absolutePath = ffStrbufCreateCopy(&instance.state.platform.exePath);
+    ffStrbufSubstrBeforeLastC(&absolutePath, '/');
+    ffStrbufAppendS(&absolutePath, "/presets/");
+    ffListFilesRecursively(absolutePath.chars, pretty);
 }
 
 static void listAvailableLogos(void)
@@ -281,12 +289,6 @@ static void listConfigPaths(void)
         uint32_t length = folder->length + (uint32_t) strlen("fastfetch") + 1 /* trailing slash */;
         ffStrbufAppendS(folder, "fastfetch/config.jsonc");
         exists = ffPathExists(folder->chars, FF_PATHTYPE_FILE);
-        if (!exists)
-        {
-            ffStrbufSubstrBefore(folder, folder->length - (uint32_t) strlen("jsonc"));
-            ffStrbufAppendS(folder, "conf");
-            exists = ffPathExists(folder->chars, FF_PATHTYPE_FILE);
-        }
         ffStrbufSubstrBefore(folder, length);
         printf("%s%s\n", folder->chars, exists ? " (*)" : "");
     }
@@ -499,9 +501,8 @@ static void optionParseConfigFile(FFdata* data, const char* key, const char* val
 
 static void printVersion()
 {
-    FFVersionResult result = {};
-    ffDetectVersion(&result);
-    printf("%s %s%s%s (%s)\n", result.projectName, result.version, result.versionTweak, result.debugMode ? "-debug" : "", result.architecture);
+    FFVersionResult* result = &ffVersionResult;
+    printf("%s %s%s%s (%s)\n", result->projectName, result->version, result->versionTweak, result->debugMode ? "-debug" : "", result->architecture);
 }
 
 static void parseCommand(FFdata* data, char* key, char* value)
@@ -677,7 +678,7 @@ static void parseArguments(FFdata* data, int argc, char** argv, void (*parser)(F
         if(i == argc - 1 || (
             argv[i + 1][0] == '-' &&
             argv[i + 1][1] != '\0' && // `-` is used as an alias for `/dev/stdin`
-            strcasecmp(argv[i], "--separator-string") != 0 // Separator string can start with a -
+            !ffStrEqualsIgnCase(argv[i], "--separator-string") // Separator string can start with a -
         )) {
             parser(data, argv[i], NULL);
         }
