@@ -75,6 +75,15 @@ static void printGPUResult(FFGPUOptions* options, uint8_t index, const FFGPUResu
     {
         FF_STRBUF_AUTO_DESTROY tempStr = ffStrbufCreate();
         ffTempsAppendNum(gpu->temperature, &tempStr, options->tempConfig, &options->moduleArgs);
+        FF_STRBUF_AUTO_DESTROY dTotal = ffStrbufCreate();
+        FF_STRBUF_AUTO_DESTROY dUsed = ffStrbufCreate();
+        FF_STRBUF_AUTO_DESTROY sTotal = ffStrbufCreate();
+        FF_STRBUF_AUTO_DESTROY sUsed = ffStrbufCreate();
+        if (gpu->dedicated.total != FF_GPU_VMEM_SIZE_UNSET) ffParseSize(gpu->dedicated.total, &dTotal);
+        if (gpu->dedicated.used != FF_GPU_VMEM_SIZE_UNSET) ffParseSize(gpu->dedicated.used, &dUsed);
+        if (gpu->shared.total != FF_GPU_VMEM_SIZE_UNSET) ffParseSize(gpu->shared.total, &sTotal);
+        if (gpu->shared.used != FF_GPU_VMEM_SIZE_UNSET) ffParseSize(gpu->shared.used, &sUsed);
+
         FF_PRINT_FORMAT_CHECKED(FF_GPU_MODULE_NAME, index, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, FF_GPU_NUM_FORMAT_ARGS, ((FFformatarg[]) {
             {FF_FORMAT_ARG_TYPE_STRBUF, &gpu->vendor, "vendor"},
             {FF_FORMAT_ARG_TYPE_STRBUF, &gpu->name, "name"},
@@ -82,10 +91,10 @@ static void printGPUResult(FFGPUOptions* options, uint8_t index, const FFGPUResu
             {FF_FORMAT_ARG_TYPE_STRBUF, &tempStr, "temperature"},
             {FF_FORMAT_ARG_TYPE_INT, &gpu->coreCount, "core-count"},
             {FF_FORMAT_ARG_TYPE_STRING, type, "type"},
-            {FF_FORMAT_ARG_TYPE_UINT64, &gpu->dedicated.total, "dedicated-total"},
-            {FF_FORMAT_ARG_TYPE_UINT64, &gpu->dedicated.used, "dedicated-used"},
-            {FF_FORMAT_ARG_TYPE_UINT64, &gpu->shared.total, "shared-total"},
-            {FF_FORMAT_ARG_TYPE_UINT64, &gpu->shared.used, "shared-used"},
+            {FF_FORMAT_ARG_TYPE_STRBUF, &dTotal, "dedicated-total"},
+            {FF_FORMAT_ARG_TYPE_STRBUF, &dUsed, "dedicated-used"},
+            {FF_FORMAT_ARG_TYPE_STRBUF, &sTotal, "shared-total"},
+            {FF_FORMAT_ARG_TYPE_STRBUF, &sUsed, "shared-used"},
             {FF_FORMAT_ARG_TYPE_STRBUF, &gpu->platformApi, "platform-api"},
             {FF_FORMAT_ARG_TYPE_DOUBLE, &gpu->frequency, "frequency"},
         }));
@@ -150,6 +159,7 @@ bool ffParseGPUCommandOptions(FFGPUOptions* options, const char* key, const char
             { "auto", FF_GPU_DETECTION_METHOD_AUTO },
             { "pci", FF_GPU_DETECTION_METHOD_PCI },
             { "vulkan", FF_GPU_DETECTION_METHOD_VULKAN },
+            { "opencl", FF_GPU_DETECTION_METHOD_OPENCL },
             { "opengl", FF_GPU_DETECTION_METHOD_OPENGL },
             {},
         });
@@ -204,6 +214,7 @@ void ffParseGPUJsonObject(FFGPUOptions* options, yyjson_val* module)
                 { "auto", FF_GPU_DETECTION_METHOD_AUTO },
                 { "pci", FF_GPU_DETECTION_METHOD_PCI },
                 { "vulkan", FF_GPU_DETECTION_METHOD_VULKAN },
+                { "opencl", FF_GPU_DETECTION_METHOD_OPENCL },
                 { "opengl", FF_GPU_DETECTION_METHOD_OPENGL },
                 {},
             });
@@ -260,6 +271,9 @@ void ffGenerateGPUJsonConfig(FFGPUOptions* options, yyjson_mut_doc* doc, yyjson_
             case FF_GPU_DETECTION_METHOD_VULKAN:
                 yyjson_mut_obj_add_str(doc, module, "detectionMethod", "vulkan");
                 break;
+            case FF_GPU_DETECTION_METHOD_OPENCL:
+                yyjson_mut_obj_add_str(doc, module, "detectionMethod", "opencl");
+                break;
             case FF_GPU_DETECTION_METHOD_OPENGL:
                 yyjson_mut_obj_add_str(doc, module, "detectionMethod", "opengl");
                 break;
@@ -350,10 +364,9 @@ void ffGenerateGPUJsonResult(FFGPUOptions* options, yyjson_mut_doc* doc, yyjson_
 
         yyjson_mut_obj_add_strbuf(doc, obj, "platformApi", &gpu->platformApi);
 
-        if (gpu->frequency == FF_GPU_FREQUENCY_UNSET)
-            yyjson_mut_obj_add_null(doc, obj, "frequency");
-        else
-            yyjson_mut_obj_add_real(doc, obj, "frequency", gpu->frequency);
+        yyjson_mut_obj_add_real(doc, obj, "frequency", gpu->frequency); // NaN will be output as "null"
+
+        yyjson_mut_obj_add_uint(doc, obj, "deviceId", gpu->deviceId);
     }
 
     FF_LIST_FOR_EACH(FFGPUResult, gpu, gpus)
