@@ -15,7 +15,7 @@ void ffPrintSwap(FFSwapOptions* options)
 
     if(error)
     {
-        ffPrintError(FF_SWAP_MODULE_NAME, 0, &options->moduleArgs, "%s", error);
+        ffPrintError(FF_SWAP_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "%s", error);
         return;
     }
 
@@ -37,19 +37,19 @@ void ffPrintSwap(FFSwapOptions* options)
         {
             if(instance.config.display.percentType & FF_PERCENTAGE_TYPE_BAR_BIT)
             {
-                ffPercentAppendBar(&str, 0, options->percent);
+                ffPercentAppendBar(&str, 0, options->percent, &options->moduleArgs);
                 ffStrbufAppendC(&str, ' ');
             }
             if(!(instance.config.display.percentType & FF_PERCENTAGE_TYPE_HIDE_OTHERS_BIT))
                 ffStrbufAppendS(&str, "Disabled");
             else
-                ffPercentAppendNum(&str, 0, options->percent, str.length > 0);
+                ffPercentAppendNum(&str, 0, options->percent, str.length > 0, &options->moduleArgs);
         }
         else
         {
             if(instance.config.display.percentType & FF_PERCENTAGE_TYPE_BAR_BIT)
             {
-                ffPercentAppendBar(&str, percentage, options->percent);
+                ffPercentAppendBar(&str, percentage, options->percent, &options->moduleArgs);
                 ffStrbufAppendC(&str, ' ');
             }
 
@@ -57,7 +57,7 @@ void ffPrintSwap(FFSwapOptions* options)
                 ffStrbufAppendF(&str, "%s / %s ", usedPretty.chars, totalPretty.chars);
 
             if(instance.config.display.percentType & FF_PERCENTAGE_TYPE_NUM_BIT)
-                ffPercentAppendNum(&str, percentage, options->percent, str.length > 0);
+                ffPercentAppendNum(&str, percentage, options->percent, str.length > 0, &options->moduleArgs);
         }
 
         ffStrbufTrimRight(&str, ' ');
@@ -66,12 +66,12 @@ void ffPrintSwap(FFSwapOptions* options)
     else
     {
         FF_STRBUF_AUTO_DESTROY percentageStr = ffStrbufCreate();
-        ffPercentAppendNum(&percentageStr, percentage, options->percent, false);
-        ffPrintFormat(FF_SWAP_MODULE_NAME, 0, &options->moduleArgs, FF_SWAP_NUM_FORMAT_ARGS, (FFformatarg[]){
-            {FF_FORMAT_ARG_TYPE_STRBUF, &usedPretty},
-            {FF_FORMAT_ARG_TYPE_STRBUF, &totalPretty},
-            {FF_FORMAT_ARG_TYPE_STRBUF, &percentageStr},
-        });
+        ffPercentAppendNum(&percentageStr, percentage, options->percent, false, &options->moduleArgs);
+        FF_PRINT_FORMAT_CHECKED(FF_SWAP_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, FF_SWAP_NUM_FORMAT_ARGS, ((FFformatarg[]){
+            {FF_FORMAT_ARG_TYPE_STRBUF, &usedPretty, "used"},
+            {FF_FORMAT_ARG_TYPE_STRBUF, &totalPretty, "total"},
+            {FF_FORMAT_ARG_TYPE_STRBUF, &percentageStr, "percentage"},
+        }));
     }
 }
 
@@ -104,7 +104,7 @@ void ffParseSwapJsonObject(FFSwapOptions* options, yyjson_val* module)
         if (ffPercentParseJsonObject(key, val, &options->percent))
             continue;
 
-        ffPrintError(FF_SWAP_MODULE_NAME, 0, &options->moduleArgs, "Unknown JSON key %s", key);
+        ffPrintError(FF_SWAP_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "Unknown JSON key %s", key);
     }
 }
 
@@ -136,11 +136,11 @@ void ffGenerateSwapJsonResult(FF_MAYBE_UNUSED FFSwapOptions* options, yyjson_mut
 
 void ffPrintSwapHelpFormat(void)
 {
-    ffPrintModuleFormatHelp(FF_SWAP_MODULE_NAME, "{1} / {2} ({3})", FF_SWAP_NUM_FORMAT_ARGS, (const char* []) {
-        "Used size",
-        "Total size",
-        "Percentage used"
-    });
+    FF_PRINT_MODULE_FORMAT_HELP_CHECKED(FF_SWAP_MODULE_NAME, "{1} / {2} ({3})", FF_SWAP_NUM_FORMAT_ARGS, ((const char* []) {
+        "Used size - used",
+        "Total size - total",
+        "Percentage used - percentage",
+    }));
 }
 
 void ffInitSwapOptions(FFSwapOptions* options)
